pub struct TopoFlags(pub(crate) u8);Expand description
Flags that define the properties of segments and edges.
Tuple Fields
0: u8Implementations
Sourceimpl TopoFlags
impl TopoFlags
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Creates new flags, truncating the given bits to valid values.
Sourcepub const fn contains(self, other: Self) -> bool
pub const fn contains(self, other: Self) -> bool
Returns true if self contains all flags in other.
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Returns true if self contains any flags in other.