UnscaledStyleMetrics

Struct UnscaledStyleMetrics 

pub struct UnscaledStyleMetrics {
    pub(crate) class_ix: u16,
    pub digits_have_same_width: bool,
    pub(crate) axes: [UnscaledAxisMetrics; 2],
}
Unscaled metrics for a single style and script.

Fields

class_ix: u16

Index of style class.

digits_have_same_width: bool

Monospaced digits?

axes: [UnscaledAxisMetrics; 2]

Per-dimension unscaled metrics.

Implementations

Source

impl UnscaledStyleMetrics

pub fn new( font: &FontRef<'_>, coords: &[NormalizedCoord], style: &StyleClass, ) -> Self

Creates a set of metrics for the given font, normalized coordinates and style class.

pub fn scale(&self, scale: Scale) -> ScaledStyleMetrics

Applies the given scale to this set of style metrics.

Source

impl UnscaledStyleMetrics

pub fn style_class(&self) -> &'static StyleClass

Returns the associated style class.

pub fn horizontal_metrics(&self) -> &UnscaledAxisMetrics

Returns unscaled metrics for the horizontal axis.

pub fn vertical_metrics(&self) -> &UnscaledAxisMetrics

Returns unscaled metrics for the vertical axis.